==> gnu-ghostscript-8.55.tar.bz2: gnu-ghostscript-8.55/src/dwsetup.h <==
/* Copyright (C) 1999, Ghostgum Software Pty Ltd.  All rights reserved.
  
  This file is part of GNU ghostscript

  GNU ghostscript is free software; you can redistribute it and/or modify it under
  the terms of the GNU General Public License as published by the Free Software
  Foundation; either version 2, or (at your option) any later version.

  GNU ghostscript is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

  You should have received a copy of the GNU General Public License along with
  ghostscript; see the file COPYING. If not, write to the Free Software Foundation,
  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.

*/


// $Id: dwsetup.h,v 1.5 2006/03/08 12:30:24 Arabidopsis Exp $

#ifndef dwsetup_INCLUDED
#  define dwsetup_INCLUDED

// Definitions for Ghostscript setup program

#ifndef IDC_STATIC
#define IDC_STATIC			-1
#endif

#define IDD_TEXTWIN                     101
#define IDD_DIRDLG                      102
#define IDR_MAIN                        200
#define IDD_MAIN                        201
#define IDC_TARGET_DIR                  202
#define IDC_TARGET_GROUP                203
#define IDC_BROWSE_DIR                  204
#define IDC_BROWSE_GROUP                205
#define IDC_README                      206
#define IDS_APPNAME                     501
#define IDS_TARGET_DIR                  502
#define IDS_TARGET_GROUP                503
#define IDC_PRODUCT_NAME                1000
#define IDC_INSTALL_FONTS               1001
#define IDC_TEXTWIN_MLE                 1002
#define IDC_TEXTWIN_COPY                1003
#define IDC_INSTALL                     1004
#define IDC_FILES                       1006
#define IDC_FOLDER                      1007
#define IDC_TARGET                      1008
#define IDC_ALLUSERS                    1009
#define IDC_COPYRIGHT                   1010
#define IDC_CJK_FONTS			1011


#endif /* dwsetup_INCLUDED */

==> gnu-ghostscript-8.56.0.tar.bz2: gnu-ghostscript-8.56.0/src/dwsetup.h <==
/* Copyright (C) 2001-2006 artofcode LLC.
   All Rights Reserved.
  
  This file is part of GNU ghostscript

  GNU ghostscript is free software; you can redistribute it and/or
  modify it under the terms of the version 2 of the GNU General Public
  License as published by the Free Software Foundation.

  GNU ghostscript is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

  You should have received a copy of the GNU General Public License along with
  ghostscript; see the file COPYING. If not, write to the Free Software Foundation,
  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.

*/


// $Id: dwsetup.h,v 1.7 2007/08/01 14:25:44 jemarch Exp $

#ifndef dwsetup_INCLUDED
#  define dwsetup_INCLUDED

// Definitions for Ghostscript setup program

#ifndef IDC_STATIC
#define IDC_STATIC			-1
#endif

#define IDD_TEXTWIN                     101
#define IDD_DIRDLG                      102
#define IDR_MAIN                        200
#define IDD_MAIN                        201
#define IDC_TARGET_DIR                  202
#define IDC_TARGET_GROUP                203
#define IDC_BROWSE_DIR                  204
#define IDC_BROWSE_GROUP                205
#define IDC_README                      206
#define IDS_APPNAME                     501
#define IDS_TARGET_DIR                  502
#define IDS_TARGET_GROUP                503
#define IDC_PRODUCT_NAME                1000
#define IDC_INSTALL_FONTS               1001
#define IDC_TEXTWIN_MLE                 1002
#define IDC_TEXTWIN_COPY                1003
#define IDC_INSTALL                     1004
#define IDC_FILES                       1006
#define IDC_FOLDER                      1007
#define IDC_TARGET                      1008
#define IDC_ALLUSERS                    1009
#define IDC_COPYRIGHT                   1010
#define IDC_CJK_FONTS			1011


#endif /* dwsetup_INCLUDED */
